==> haskell-unicode-transforms-0.4.0.1-176.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-transforms
version:              0.4.0.1
visibility:           public
id:                   unicode-transforms-0.4.0.1-6C8M98Uj8qbEfETc6Lwbgj
key:                  unicode-transforms-0.4.0.1-6C8M98Uj8qbEfETc6Lwbgj
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  d2104b54db05d9402af05a0bc7774521
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unicode-transforms-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unicode-transforms-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unicode-transforms-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-transforms
hs-libraries:         HSunicode-transforms-0.4.0.1-6C8M98Uj8qbEfETc6Lwbgj
depends:
    base-4.18.2.1 bytestring-0.11.5.3 ghc-prim-0.10.0 text-2.0.2
    unicode-data-0.6.0-BVVN0MBvBx81WCoEDH1IfM

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.4.0.1-177-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-transforms
version:              0.4.0.1
visibility:           public
id:                   unicode-transforms-0.4.0.1-8iUmpGDdbp7ICIQfCprjLO
key:                  unicode-transforms-0.4.0.1-8iUmpGDdbp7ICIQfCprjLO
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  ab686e61d48e1a6d4e3c1fe900f6d6f2
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unicode-transforms-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unicode-transforms-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unicode-transforms-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-transforms
hs-libraries:         HSunicode-transforms-0.4.0.1-8iUmpGDdbp7ICIQfCprjLO
depends:
    base-4.18.2.1 bytestring-0.11.5.3 ghc-prim-0.10.0 text-2.0.2
    unicode-data-0.6.0-LuIlhI8JR792MVHCFlOTv6

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
